@@ -14,16 +14,10 @@ import (
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/version"
 	"github.com/anchore/grype/grype/vulnerability"
+	"github.com/anchore/syft/syft/cpe"
 	syftPkg "github.com/anchore/syft/syft/pkg"
 )
 
-func must(c syftPkg.CPE, e error) syftPkg.CPE {
-	if e != nil {
-		panic(e)
-	}
-	return c
-}
-
 var _ grypeDB.VulnerabilityStoreReader = (*mockVulnStore)(nil)
 
 type mockVulnStore struct {
@@ -171,9 +165,9 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "match from range",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.5:rando1:*:ra:*:ruby:*:*")),
-					must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.5:rando4:*:re:*:rails:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.5:rando1:*:ra:*:ruby:*:*"),
+					cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.5:rando4:*:re:*:rails:*:*"),
 				},
 				Name:     "activerecord",
 				Version:  "3.7.5",
@@ -187,9 +181,9 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2017-fake-1",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.5:rando1:*:ra:*:ruby:*:*")),
-							must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.5:rando4:*:re:*:rails:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.5:rando1:*:ra:*:ruby:*:*"),
+							cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.5:rando4:*:re:*:rails:*:*"),
 						},
 						Name:     "activerecord",
 						Version:  "3.7.5",
@@ -218,9 +212,9 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "multiple matches",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.3:rando1:*:ra:*:ruby:*:*")),
-					must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.3:rando4:*:re:*:rails:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.3:rando1:*:ra:*:ruby:*:*"),
+					cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.3:rando4:*:re:*:rails:*:*"),
 				},
 				Name:     "activerecord",
 				Version:  "3.7.3",
@@ -234,9 +228,9 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2017-fake-1",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.3:rando1:*:ra:*:ruby:*:*")),
-							must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.3:rando4:*:re:*:rails:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.3:rando1:*:ra:*:ruby:*:*"),
+							cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.3:rando4:*:re:*:rails:*:*"),
 						},
 						Name:     "activerecord",
 						Version:  "3.7.3",
@@ -269,9 +263,9 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2017-fake-2",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.3:rando1:*:ra:*:ruby:*:*")),
-							must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:3.7.3:rando4:*:re:*:rails:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.3:rando1:*:ra:*:ruby:*:*"),
+							cpe.Must("cpe:2.3:*:activerecord:activerecord:3.7.3:rando4:*:re:*:rails:*:*"),
 						},
 						Name:     "activerecord",
 						Version:  "3.7.3",
@@ -301,8 +295,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "exact match",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:*:*:activerecord:4.0.1:*:*:*:*:*:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:*:*:activerecord:4.0.1:*:*:*:*:*:*:*"),
 				},
 				Name:     "activerecord",
 				Version:  "4.0.1",
@@ -316,8 +310,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2017-fake-3",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:*:*:activerecord:4.0.1:*:*:*:*:*:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:*:*:activerecord:4.0.1:*:*:*:*:*:*:*"),
 						},
 						Name:     "activerecord",
 						Version:  "4.0.1",
@@ -357,8 +351,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "fuzzy version match",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:*:awesome:awesome:98SE1:rando1:*:ra:*:dunno:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:*:awesome:awesome:98SE1:rando1:*:ra:*:dunno:*:*"),
 				},
 				Name:    "awesome",
 				Version: "98SE1",
@@ -370,8 +364,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2017-fake-4",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:*:awesome:awesome:98SE1:rando1:*:ra:*:dunno:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:*:awesome:awesome:98SE1:rando1:*:ra:*:dunno:*:*"),
 						},
 						Name:    "awesome",
 						Version: "98SE1",
@@ -399,8 +393,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "multiple matched CPEs",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*"),
 				},
 				Name:     "multiple",
 				Version:  "1.0",
@@ -414,8 +408,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2017-fake-5",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*"),
 						},
 						Name:     "multiple",
 						Version:  "1.0",
@@ -448,8 +442,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "filtered out match due to target_sw mismatch",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:*:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:*:*:*"),
 				},
 				Name:     "funfun",
 				Version:  "5.2.1",
@@ -461,8 +455,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "target_sw mismatch with unsupported target_sw",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:*:sw:sw:*:*:*:*:*:*:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:*:sw:sw:*:*:*:*:*:*:*:*"),
 				},
 				Name:     "sw",
 				Version:  "0.1",
@@ -475,8 +469,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2017-fake-7",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:*:sw:sw:*:*:*:*:*:*:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:*:sw:sw:*:*:*:*:*:*:*:*"),
 						},
 						Name:     "sw",
 						Version:  "0.1",
@@ -507,11 +501,11 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "match included even though multiple cpes are mismatch",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:rust:*:*")),
-					must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:rails:*:*")),
-					must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:ruby:*:*")),
-					must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:python:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:rust:*:*"),
+					cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:rails:*:*"),
+					cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:ruby:*:*"),
+					cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:python:*:*"),
 				},
 				Name:     "funfun",
 				Version:  "5.2.1",
@@ -524,11 +518,11 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2017-fake-6",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:rust:*:*")),
-							must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:rails:*:*")),
-							must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:ruby:*:*")),
-							must(syftPkg.NewCPE("cpe:2.3:*:funfun:funfun:*:*:*:*:*:python:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:rust:*:*"),
+							cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:rails:*:*"),
+							cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:ruby:*:*"),
+							cpe.Must("cpe:2.3:*:funfun:funfun:*:*:*:*:*:python:*:*"),
 						},
 						Name:     "funfun",
 						Version:  "5.2.1",
@@ -560,8 +554,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "Ensure target_sw mismatch does not apply to java packages",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*"),
 				},
 				Name:     "handlebars",
 				Version:  "0.1",
@@ -574,8 +568,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2021-23369",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*"),
 						},
 						Name:     "handlebars",
 						Version:  "0.1",
@@ -606,8 +600,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 		{
 			name: "Ensure target_sw mismatch does not apply to java jenkins plugins packages",
 			p: pkg.Package{
-				CPEs: []syftPkg.CPE{
-					must(syftPkg.NewCPE("cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*")),
+				CPEs: []cpe.CPE{
+					cpe.Must("cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*"),
 				},
 				Name:     "handlebars",
 				Version:  "0.1",
@@ -620,8 +614,8 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 						ID: "CVE-2021-23369",
 					},
 					Package: pkg.Package{
-						CPEs: []syftPkg.CPE{
-							must(syftPkg.NewCPE("cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*")),
+						CPEs: []cpe.CPE{
+							cpe.Must("cpe:2.3:a:handlebarsjs:handlebars:*:*:*:*:*:*:*:*"),
 						},
 						Name:     "handlebars",
 						Version:  "0.1",
@@ -692,9 +686,9 @@ func TestFilterCPEsByVersion(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
 			// format strings to CPE objects...
-			vulnerabilityCPEs := make([]syftPkg.CPE, len(test.vulnerabilityCPEs))
+			vulnerabilityCPEs := make([]cpe.CPE, len(test.vulnerabilityCPEs))
 			for idx, c := range test.vulnerabilityCPEs {
-				vulnerabilityCPEs[idx] = must(syftPkg.NewCPE(c))
+				vulnerabilityCPEs[idx] = cpe.Must(c)
 			}
 
 			versionObj, err := version.NewVersion(test.version, version.UnknownFormat)
