@@ -70,9 +70,10 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 		string(syftPkg.PortagePkg),
 		string(syftPkg.CocoapodsPkg),
 		string(syftPkg.HackagePkg),
+		string(syftPkg.NixPkg),
 		string(syftPkg.JenkinsPluginPkg), // package type cannot be inferred for all formats
-		string(syftPkg.Elixir),
-		string(syftPkg.Erlang),
+		string(syftPkg.LinuxKernelPkg),
+		string(syftPkg.LinuxKernelModulePkg),
 	)
 	observedPkgTypes := strset.New()
 
